@@ -3,11 +3,11 @@ package DBIx::dbMan::Extension::Transaction;
 use strict;
 use base 'DBIx::dbMan::Extension';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 1;
 
-sub IDENTIFICATION { return "000001-000022-000008"; }
+sub IDENTIFICATION { return "000001-000022-000009"; }
 
 sub preference { return 0; }
 
@@ -15,7 +15,9 @@ sub known_actions { return [ qw/TRANSACTION/ ]; }
 
 sub init {
 	my $obj = shift;
+
 	$obj->{prompt_num} = $obj->{-interface}->register_prompt(1000);
+	$obj->{prompt_title} = $obj->{-config}->prompt_transaction || 'TRANSACTION';
 }
 
 sub menu {
@@ -84,7 +86,7 @@ sub handle_action {
 	}
 
 	if ($obj->{-dbi}->in_transaction) {
-		$obj->{-interface}->prompt($obj->{prompt_num},'TRANSACTION');
+		$obj->{-interface}->prompt($obj->{prompt_num},$obj->{prompt_title});
 	} else {
 		$obj->{-interface}->prompt($obj->{prompt_num},'');
 	}
@@ -96,7 +98,7 @@ sub handle_action {
 sub done {
 	my $obj = shift;
 	
-	$obj->{-interface}->deregister_prompt($obj->{-prompt_num});
+	$obj->{-interface}->deregister_prompt($obj->{prompt_num});
 
 	for (@{$obj->{-dbi}->list('active')}) {
 		my $name = $_->{name};
